@@ -1,9 +1,11 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def indent(levels):
-    '''
+    ''' 
 
     '''
 
@@ -11,7 +13,7 @@ def indent(levels):
 
 
 def keyconfig_export_as_data(wm, kc, filepath, all_keymaps):
-    '''
+    ''' 
 
     '''
 
@@ -19,7 +21,7 @@ def keyconfig_export_as_data(wm, kc, filepath, all_keymaps):
 
 
 def keyconfig_import_from_data(name, keyconfig_data):
-    '''
+    ''' 
 
     '''
 
@@ -27,7 +29,7 @@ def keyconfig_import_from_data(name, keyconfig_data):
 
 
 def keyconfig_init_from_data(kc, keyconfig_data):
-    '''
+    ''' 
 
     '''
 
@@ -35,7 +37,7 @@ def keyconfig_init_from_data(kc, keyconfig_data):
 
 
 def keyconfig_merge(kc1, kc2):
-    '''
+    ''' 
 
     '''
 
@@ -43,7 +45,7 @@ def keyconfig_merge(kc1, kc2):
 
 
 def keymap_init_from_data(km, km_items, is_modal):
-    '''
+    ''' 
 
     '''
 
@@ -51,7 +53,7 @@ def keymap_init_from_data(km, km_items, is_modal):
 
 
 def kmi_args_as_data(kmi):
-    '''
+    ''' 
 
     '''
 
@@ -59,7 +61,7 @@ def kmi_args_as_data(kmi):
 
 
 def repr_f32(f):
-    '''
+    ''' 
 
     '''
 
@@ -67,7 +69,7 @@ def repr_f32(f):
 
 
 def round_float_32(f):
-    '''
+    ''' 
 
     '''
 
