@@ -2,17 +2,10 @@ import sys
 import typing
 import bpy_types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class AlignObjects(bpy_types.Operator):
-    align_axis = None
-    ''' '''
-
-    align_mode = None
-    ''' '''
-
-    bb_quality = None
-    ''' '''
-
     bl_idname = None
     ''' '''
 
@@ -28,12 +21,6 @@ class AlignObjects(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
-    relative_to = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -46,6 +33,18 @@ class AlignObjects(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -76,6 +75,12 @@ class AlignObjects(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -130,6 +135,18 @@ class AlignObjects(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -166,7 +183,7 @@ def worldspace_bounds_from_object_bounds(bb_world):
     pass
 
 
-def worldspace_bounds_from_object_data(scene, obj):
+def worldspace_bounds_from_object_data(depsgraph, obj):
     ''' 
 
     '''
