@@ -1,20 +1,31 @@
 import sys
 import typing
+import bl_ui.utils
 import bpy_types
 
 GenericType = typing.TypeVar("GenericType")
 
 
-class FLUID_MT_presets(bpy_types.Menu, bpy_types._GenericUI):
+class FLUID_PT_presets(bl_ui.utils.PresetPanel, bpy_types.Panel,
+                       bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
+    bl_region_type = None
+    ''' '''
+
     bl_rna = None
     ''' '''
 
+    bl_space_type = None
+    ''' '''
+
     id_data = None
     ''' '''
 
+    preset_add_operator = None
+    ''' '''
+
     preset_operator = None
     ''' '''
 
@@ -45,19 +56,19 @@ class FLUID_MT_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, _context):
+    def draw(self, context):
         ''' 
 
         '''
         pass
 
-    def draw_collapsible(self, context, layout):
+    def draw_menu(self, layout, text):
         ''' 
 
         '''
         pass
 
-    def draw_preset(self, _context):
+    def draw_panel_header(self, layout):
         ''' 
 
         '''
@@ -1281,6 +1292,18 @@ class PHYSICS_PT_diffusion(PhysicButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def draw_header(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_header_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
