@@ -1,6 +1,8 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def clear_by_owner(owner):
     ''' Clear all subscribers using this owner.
@@ -19,13 +21,13 @@ def publish_rna(data, owner, args, notify):
     pass
 
 
-def subscribe_rna(data, owner, args, notify, options: set = 'set()'):
+def subscribe_rna(data, owner, args, notify, options: typing.Set = 'set()'):
     ''' 
 
     :param key: Represents the type of data being subscribed to Arguments include - bpy.types.Property instance. - bpy.types.Struct type. - ( bpy.types.Struct , str) type and property name.
     :param owner: Handle for this subscription (compared by identity).
     :param options: Change the behavior of the subscriber. - PERSISTENT when set, the subscriber will be kept when remapping ID data.
-    :type options: set
+    :type options: typing.Set
     '''
 
     pass
