@@ -2,12 +2,19 @@ import sys
 import typing
 import bpy.types
 
+GenericType = typing.TypeVar("GenericType")
 
-def fbx(filepath: str = "",
+
+def fbx(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         directory: str = "",
         filter_glob: str = "*.fbx",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: bpy.types.
+        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
         ui_tab: typing.Union[str, int] = 'MAIN',
         use_manual_orientation: bool = False,
         global_scale: float = 1.0,
@@ -31,6 +38,9 @@ def fbx(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Load a FBX file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param directory: directory
@@ -38,7 +48,7 @@ def fbx(filepath: str = "",
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
     :param ui_tab: ui_tab, Import options categories * MAIN Main, Main basic settings. * ARMATURE Armatures, Armature-related settings.
     :type ui_tab: typing.Union[str, int]
     :param use_manual_orientation: Manual Orientation, Specify orientation and scale, instead of using embedded data in FBX file
@@ -86,10 +96,15 @@ def fbx(filepath: str = "",
     pass
 
 
-def gltf(filepath: str = "",
+def gltf(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: bool = None,
+         *,
+         filepath: str = "",
          filter_glob: str = "*.glb;*.gltf",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: bpy.types.
+         bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
          loglevel: int = 0,
          import_pack_images: bool = True,
          import_shading: typing.Union[str, int] = 'NORMALS',
@@ -97,12 +112,15 @@ def gltf(filepath: str = "",
          guess_original_bind_pose: bool = True):
     ''' Load a glTF 2.0 file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
     :param loglevel: Log Level, Log Level
     :type loglevel: int
     :param import_pack_images: Pack Images, Pack all images into .blend file
@@ -118,7 +136,12 @@ def gltf(filepath: str = "",
     pass
 
 
-def obj(filepath: str = "",
+def obj(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         filter_glob: str = "*.obj;*.mtl",
         use_edges: bool = True,
         use_smooth_groups: bool = True,
@@ -132,6 +155,9 @@ def obj(filepath: str = "",
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Load a Wavefront OBJ File
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
@@ -161,12 +187,20 @@ def obj(filepath: str = "",
     pass
 
 
-def x3d(filepath: str = "",
+def x3d(override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        filepath: str = "",
         filter_glob: str = "*.x3d;*.wrl",
         axis_forward: typing.Union[str, int] = 'Z',
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Import an X3D or VRML2 file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
