@@ -1,16 +1,30 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def bake_animation():
+def bake_animation(override_context: typing.
+                   Union[typing.Dict, 'bpy.types.Context'] = None,
+                   execution_context: typing.Union[str, int] = None,
+                   undo: bool = None):
     ''' Update the audio animation cache
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def mixdown(filepath: str = "",
+def mixdown(override_context: typing.Union[typing.
+                                           Dict, 'bpy.types.Context'] = None,
+            execution_context: typing.Union[str, int] = None,
+            undo: bool = None,
+            *,
+            filepath: str = "",
             check_existing: bool = True,
             filter_blender: bool = False,
             filter_backup: bool = False,
@@ -40,6 +54,9 @@ def mixdown(filepath: str = "",
             split_channels: bool = False):
     ''' Mix the scene's audio to a sound file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -101,7 +118,12 @@ def mixdown(filepath: str = "",
     pass
 
 
-def open(filepath: str = "",
+def open(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: bool = None,
+         *,
+         filepath: str = "",
          hide_props_region: bool = True,
          filter_blender: bool = False,
          filter_backup: bool = False,
@@ -129,6 +151,9 @@ def open(filepath: str = "",
          mono: bool = False):
     ''' Load a sound file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -186,7 +211,12 @@ def open(filepath: str = "",
     pass
 
 
-def open_mono(filepath: str = "",
+def open_mono(override_context: typing.Union[typing.
+                                             Dict, 'bpy.types.Context'] = None,
+              execution_context: typing.Union[str, int] = None,
+              undo: bool = None,
+              *,
+              filepath: str = "",
               hide_props_region: bool = True,
               filter_blender: bool = False,
               filter_backup: bool = False,
@@ -214,6 +244,9 @@ def open_mono(filepath: str = "",
               mono: bool = True):
     ''' Load a sound file as mono
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -271,17 +304,32 @@ def open_mono(filepath: str = "",
     pass
 
 
-def pack():
+def pack(override_context: typing.Union[typing.
+                                        Dict, 'bpy.types.Context'] = None,
+         execution_context: typing.Union[str, int] = None,
+         undo: bool = None):
     ''' Pack the sound into the current blend file
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
+def unpack(override_context: typing.Union[typing.
+                                          Dict, 'bpy.types.Context'] = None,
+           execution_context: typing.Union[str, int] = None,
+           undo: bool = None,
+           *,
+           method: typing.Union[str, int] = 'USE_LOCAL',
+           id: str = ""):
     ''' Unpack the sound to the samples filename
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param method: Method, How to unpack
     :type method: typing.Union[str, int]
     :param id: Sound Name, Sound data-block name to unpack
@@ -291,9 +339,15 @@ def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
     pass
 
 
-def update_animation_flags():
+def update_animation_flags(override_context: typing.
+                           Union[typing.Dict, 'bpy.types.Context'] = None,
+                           execution_context: typing.Union[str, int] = None,
+                           undo: bool = None):
     ''' Update animation flags
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
