@@ -251,12 +251,16 @@ def eyedropper_driver(override_context: typing.
 def eyedropper_gpencil_color(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
-                             undo: bool = None):
+                             undo: bool = None,
+                             *,
+                             mode: typing.Union[str, int] = 'MATERIAL'):
     ''' Sample a color from the Blender Window and create Grease Pencil material
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
+    :param mode: Mode
+    :type mode: typing.Union[str, int]
     '''
 
     pass
