@@ -1,8 +1,9 @@
 import sys
 import typing
-import bpy.types
 import mathutils
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class AdjacencyIterator:
     ''' Class hierarchy: Iterator > AdjacencyIterator Class for representing adjacency iterators used in the chaining process. An AdjacencyIterator is created in the increment() and decrement() methods of a ChainingIterator and passed to the traverse() method of the ChainingIterator.
@@ -253,11 +254,11 @@ class Curve:
         '''
         pass
 
-    def __init__(self, brother: 'bpy.types.Curve'):
+    def __init__(self, brother: 'Curve'):
         ''' Copy Constructor.
 
         :param brother: A Curve object.
-        :type brother: 'bpy.types.Curve'
+        :type brother: 'Curve'
         '''
         pass
 
@@ -269,19 +270,19 @@ class Curve:
         '''
         pass
 
-    def push_vertex_back(self, vertex: typing.Union['SVertex', 'CurvePoint']):
+    def push_vertex_back(self, vertex: 'SVertex'):
         ''' Adds a single vertex at the end of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: typing.Union['SVertex', 'CurvePoint']
+        :type vertex: 'SVertex'
         '''
         pass
 
-    def push_vertex_front(self, vertex: typing.Union['SVertex', 'CurvePoint']):
+    def push_vertex_front(self, vertex: 'SVertex'):
         ''' Adds a single vertex at the front of the Curve.
 
         :param vertex: A vertex object.
-        :type vertex: typing.Union['SVertex', 'CurvePoint']
+        :type vertex: 'SVertex'
         '''
         pass
 
@@ -505,16 +506,16 @@ class FEdgeSharp:
     :type: int
     '''
 
-    material_left: 'bpy.types.Material' = None
+    material_left: 'Material' = None
     ''' The material of the face lying on the left of the FEdge.
 
-    :type: 'bpy.types.Material'
+    :type: 'Material'
     '''
 
-    material_right: 'bpy.types.Material' = None
+    material_right: 'Material' = None
     ''' The material of the face lying on the right of the FEdge. If this FEdge is a border, it has no Face on its right and therefore no material.
 
-    :type: 'bpy.types.Material'
+    :type: 'Material'
     '''
 
     normal_left: 'mathutils.Vector' = None
@@ -564,10 +565,10 @@ class FEdgeSmooth:
     :type: bool
     '''
 
-    material: 'bpy.types.Material' = None
+    material: 'Material' = None
     ''' The material of the face that this FEdge is running across.
 
-    :type: 'bpy.types.Material'
+    :type: 'Material'
     '''
 
     material_index: int = None
@@ -754,12 +755,11 @@ class Interface0DIterator:
         '''
         pass
 
-    def __init__(self, it: typing.Union[
-            'StrokeVertexIterator', 'CurvePointIterator', 'SVertexIterator']):
+    def __init__(self, it: 'SVertexIterator'):
         ''' Construct a nested Interface0DIterator that can be the argument of a Function0D.
 
         :param it: An iterator object to be nested.
-        :type it: typing.Union['StrokeVertexIterator', 'CurvePointIterator', 'SVertexIterator']
+        :type it: 'SVertexIterator'
         '''
         pass
 
@@ -934,37 +934,30 @@ class Material:
         '''
         pass
 
-    def __init__(self, brother: 'bpy.types.Material'):
+    def __init__(self, brother: 'Material'):
         ''' Copy constructor.
 
         :param brother: A Material object.
-        :type brother: 'bpy.types.Material'
+        :type brother: 'Material'
         '''
         pass
 
-    def __init__(self, line: typing.Union[typing.List[float], typing.
-                                          List['mathutils.Vector']],
-                 diffuse: typing.Union[typing.List[float], typing.
-                                       List['mathutils.Vector']],
-                 ambient: typing.Union[typing.List[float], typing.
-                                       List['mathutils.Vector']],
-                 specular: typing.Union[typing.List[float], typing.
-                                        List['mathutils.Vector']],
-                 emission: typing.Union[typing.List[float], typing.
-                                        List['mathutils.Vector']],
-                 shininess: float, priority: int):
+    def __init__(self, line: 'mathutils.Vector', diffuse: 'mathutils.Vector',
+                 ambient: 'mathutils.Vector', specular: 'mathutils.Vector',
+                 emission: 'mathutils.Vector', shininess: float,
+                 priority: int):
         ''' Builds a Material from its line, diffuse, ambient, specular, emissive colors, a shininess coefficient and line color priority.
 
         :param line: The line color.
-        :type line: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
+        :type line: 'mathutils.Vector'
         :param diffuse: The diffuse color.
-        :type diffuse: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
+        :type diffuse: 'mathutils.Vector'
         :param ambient: The ambient color.
-        :type ambient: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
+        :type ambient: 'mathutils.Vector'
         :param specular: The specular color.
-        :type specular: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
+        :type specular: 'mathutils.Vector'
         :param emission: The emissive color.
-        :type emission: typing.Union[typing.List[float], typing.List['mathutils.Vector']]
+        :type emission: 'mathutils.Vector'
         :param shininess: The shininess coefficient.
         :type shininess: float
         :param priority: The line color priority.
@@ -1009,21 +1002,21 @@ class Noise:
         '''
         pass
 
-    def smoothNoise2(self, v: typing.List['mathutils.Vector']) -> float:
+    def smoothNoise2(self, v: 'mathutils.Vector') -> float:
         ''' Returns a smooth noise value for a 2D element.
 
         :param v: Two-dimensional sample point.
-        :type v: typing.List['mathutils.Vector']
+        :type v: 'mathutils.Vector'
         :rtype: float
         :return: A smooth noise value.
         '''
         pass
 
-    def smoothNoise3(self, v: typing.List['mathutils.Vector']) -> float:
+    def smoothNoise3(self, v: 'mathutils.Vector') -> float:
         ''' Returns a smooth noise value for a 3D element.
 
         :param v: Three-dimensional sample point.
-        :type v: typing.List['mathutils.Vector']
+        :type v: 'mathutils.Vector'
         :rtype: float
         :return: A smooth noise value.
         '''
@@ -1047,14 +1040,14 @@ class Noise:
         pass
 
     def turbulence2(self,
-                    v: typing.List['mathutils.Vector'],
+                    v: 'mathutils.Vector',
                     freq: float,
                     amp: float,
                     oct: int = 4) -> float:
         ''' Returns a noise value for a 2D element.
 
         :param v: Two-dimensional sample point.
-        :type v: typing.List['mathutils.Vector']
+        :type v: 'mathutils.Vector'
         :param freq: Noise frequency.
         :type freq: float
         :param amp: Amplitude.
@@ -1067,14 +1060,14 @@ class Noise:
         pass
 
     def turbulence3(self,
-                    v: typing.List['mathutils.Vector'],
+                    v: 'mathutils.Vector',
                     freq: float,
                     amp: float,
                     oct: int = 4) -> float:
         ''' Returns a noise value for a 3D element.
 
         :param v: Three-dimensional sample point.
-        :type v: typing.List['mathutils.Vector']
+        :type v: 'mathutils.Vector'
         :param freq: Noise frequency.
         :type freq: float
         :param amp: Amplitude.
@@ -1394,10 +1387,10 @@ class SVertex:
     ''' Class hierarchy: Interface0D > SVertex Class to define a vertex of the embedding.
     '''
 
-    curvatures: tuple = None
+    curvatures: typing.Tuple = None
     ''' Curvature information expressed in the form of a seven-element tuple (K1, e1, K2, e2, Kr, er, dKr), where K1 and K2 are scalar values representing the first (maximum) and second (minimum) principal curvatures at this SVertex, respectively; e1 and e2 are three-dimensional vectors representing the first and second principal directions, i.e. the directions of the normal plane where the curvature takes its maximum and minimum values, respectively; and Kr, er and dKr are the radial curvature, radial direction, and the derivative of the radial curvature at this SVertex, respectively.
 
-    :type: tuple
+    :type: typing.Tuple
     '''
 
     id: 'Id' = None
@@ -1468,11 +1461,11 @@ class SVertex:
         '''
         pass
 
-    def add_normal(self, normal: typing.List['mathutils.Vector']):
+    def add_normal(self, normal: 'mathutils.Vector'):
         ''' Adds a normal to the SVertex's set of normals. If the same normal is already in the set, nothing changes.
 
         :param normal: A three-dimensional vector.
-        :type normal: typing.List['mathutils.Vector']
+        :type normal: 'mathutils.Vector'
         '''
         pass
 
@@ -1805,25 +1798,23 @@ class StrokeAttribute:
         '''
         pass
 
-    def set_attribute_vec2(self, name: str,
-                           value: typing.List['mathutils.Vector']):
+    def set_attribute_vec2(self, name: str, value: 'mathutils.Vector'):
         ''' Adds a user-defined attribute of two-dimensional vector type. If there is no attribute of the given name, it is added. Otherwise, the new value replaces the old one.
 
         :param name: The name of the attribute.
         :type name: str
         :param value: The attribute value.
-        :type value: typing.List['mathutils.Vector']
+        :type value: 'mathutils.Vector'
         '''
         pass
 
-    def set_attribute_vec3(self, name: str,
-                           value: typing.List['mathutils.Vector']):
+    def set_attribute_vec3(self, name: str, value: 'mathutils.Vector'):
         ''' Adds a user-defined attribute of three-dimensional vector type. If there is no attribute of the given name, it is added. Otherwise, the new value replaces the old one.
 
         :param name: The name of the attribute.
         :type name: str
         :param value: The attribute value.
-        :type value: typing.List['mathutils.Vector']
+        :type value: 'mathutils.Vector'
         '''
         pass
 
@@ -2644,10 +2635,10 @@ class ViewShape:
     :type: 'Id'
     '''
 
-    library_path: typing.Union[str, 'ViewShape'] = None
+    library_path: str = None
     ''' The library path of the ViewShape.
 
-    :type: typing.Union[str, 'ViewShape']
+    :type: str
     '''
 
     name: str = None
